@@ -1,7 +1,9 @@
 from speedrunapi import Game_Requests
 from datetime import datetime
 import urllib.error
-import speedrunapi as sr
+import speedrunapi.translation as tr
+import http.client
+from .errors import URLerror
 
 class Game:
     """Data about a game on speedrun.com
@@ -49,40 +51,52 @@ class Game:
 
     @property
     def regions(self):
-        """Returns the regions of a game on speedrun.com as a dictionary
-        (wont look like a real region(soon to add a way to translate these))"""
+        """Returns the regions of a game on speedrun.com as a dictionary"""
         final_regions = []
         game_regions = self.game_data.game_data["regions"]
         for region in range(len(game_regions)):
-            final_regions.append(sr.translate_region('e6lxy1dz'))
+            final_regions.append(tr.translate_region(game_regions[region]))
         return final_regions
 
     @property
     def platforms(self):
-        """Returns the platforms of a game on speedrun.com as a dictionary
-        (wont look like a real platform(soon to add a way to translate these))"""
-        return self.game_data.game_data["platforms"]
-
+        """Returns the platforms of a game on speedrun.com as a dictionary"""
+        final_platforms = []
+        game_platforms = self.game_data.game_data["platforms"]
+        for platform in range(len(game_platforms)):
+            final_platforms.append(tr.translate_platform(game_platforms[platform]))
+        return final_platforms
+    
     @property
     def genres(self):
-        """Returns the genres of a game on speedrun.com as a dictionary
-        (wont look like a real genre(soon to add a way to translate these))"""
-        return self.game_data.game_data["genres"]
+        """Returns the genres of a game on speedrun.com as a dictionary"""
+        final_genres = []
+        game_genres = self.game_data.game_data["genres"]
+        for genre in range(len(game_genres)):
+            final_genres.append(tr.translate_genre(game_genres[genre]))
+        return final_genres
 
     @property
     def engines(self):
-        """Returns the engines of a game on speedrun.com as a dictionary
-        (wont look like a real engine(soon to add a way to translate these))"""
-        return self.game_data.game_data["engines"]
+        """Returns the engines of a game on speedrun.com as a dictionary"""
+        final_engines = []
+        game_engines = self.game_data.game_data["engines"]
+        for engine in range(len(game_engines)):
+            final_engines.append(tr.translate_engine(game_engines[engine]))
+        return final_engines
 
     @property
     def admins(self):
-        """Returns the developers,publishers, and moderators of a game on speedrun.com as a dictionary"""
+        """Returns the developers, publishers, and moderators of a game on speedrun.com as a dictionary"""
         final_admins = []
         admin_list = ["developers", "publishers", "moderators"]
         for admin in admin_list:
             admins = self.game_data.game_data.get(admin, [])
-            final_admins.append(admins)
+            print(admins)
+            if type(admins) == dict:
+                admins = next(iter(admins))
+                print(admins)
+            final_admins.append(tr.translate_user_id(admins))
         return final_admins
 
     @property
@@ -94,6 +108,7 @@ class Game:
             return date_formatted.strftime("%Y-%m-%d")
         except TypeError:
             return "Cannot create join date"
+    
     # special cases
     @property
     def levels(self):
@@ -133,6 +148,7 @@ class Game:
             return self.game_data.game_data_response
         except urllib.error.HTTPError:
             return "Derived Games Not Found"
+    
     @property
     def romhacks(self):
         """DEPRICATED returns the same as derived games, here for backwards compatiblilty
@@ -147,13 +163,15 @@ class Game:
         return self.game_data.game_data_response
 
     def __init__(self, game):
-        self.game = game
-        self.format_name
-        self.quick_game_data = Game_Requests(self.formated_game_name)
-        self.quick_game_data.game_reqest_quick()
-        self.game_id = self.id
-        self.game_data = Game_Requests(self.id)
-        self.game_data.game_request()
-
-game = Game('sms')
-print(game.regions)
+        try:
+            self.game = game
+            self.format_name
+            self.quick_game_data = Game_Requests(self.formated_game_name)
+            self.quick_game_data.game_reqest_quick()
+            self.game_id = self.id
+            self.game_data = Game_Requests(self.id)
+            self.game_data.game_request()
+        except http.client.InvalidURL as e:
+            details = e.args[0].split("'")[2]
+            raise URLerror(f'{details}\nCheck to make sure the name acctualy has no alphanumeric characters/spaces')
+        
\ No newline at end of file
